devices

package module
v0.0.0-...-84d257b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 13, 2021 License: Apache-2.0 Imports: 2 Imported by: 0

README

devices

Go module with device-specific data for debugWIRE-capable AVR microcontrollers.

This module is based on atdf files extracted from device family packs downloaded directly from https://packs.download.microchip.com/

  • Microchip ATtiny Series Device Support (2.5.116)
  • Microchip ATmega Series Device Support (2.3.126)

The packs are distributed under an Apache License, see atfd/LICENSE.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MCU

type MCU struct {
	// contains filtered or unexported fields
}

func GetAll

func GetAll() []*MCU

func GetByName

func GetByName(name string) (*MCU, error)

func GetBySignature

func GetBySignature(signature uint16) (*MCU, error)

func (*MCU) DWENMask

func (m *MCU) DWENMask() byte

func (*MCU) EEAR

func (m *MCU) EEAR() SFR

func (*MCU) EECR

func (m *MCU) EECR() SFR

func (*MCU) EEDR

func (m *MCU) EEDR() SFR

func (*MCU) EEPROMSize

func (m *MCU) EEPROMSize() uint16

func (*MCU) FlashPageSize

func (m *MCU) FlashPageSize() uint16

func (*MCU) FlashSize

func (m *MCU) FlashSize() uint16

func (*MCU) NRWWOffset

func (m *MCU) NRWWOffset() uint16

func (*MCU) Name

func (m *MCU) Name() string

func (*MCU) SP

func (m *MCU) SP() SFR

func (*MCU) SPMCSR

func (m *MCU) SPMCSR() SFR

func (*MCU) SREG

func (m *MCU) SREG() SFR

func (*MCU) Signature

func (m *MCU) Signature() uint16

type SFR

type SFR struct {
	// contains filtered or unexported fields
}

func (SFR) Io8

func (s SFR) Io8() byte

func (SFR) Io16

func (s SFR) Io16() uint16

func (SFR) Mem8

func (s SFR) Mem8() byte

func (SFR) Mem16

func (s SFR) Mem16() uint16

func (SFR) Size

func (s SFR) Size() byte

Jump to